package com.ruoyi.ems.record.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ems.record.mapper.EmsVibrationInstantMapper;
import com.ruoyi.ems.record.domain.EmsVibrationInstant;
import com.ruoyi.ems.record.service.IEmsVibrationInstantService;

/**
 * 震动实时数据Service业务层处理
 * 
 * @author ZangCH
 * @date 2024-08-22
 */
@Service
public class EmsVibrationInstantServiceImpl implements IEmsVibrationInstantService 
{
    @Autowired
    private EmsVibrationInstantMapper emsVibrationInstantMapper;

    /**
     * 查询震动实时数据
     * 
     * @param objId 震动实时数据主键
     * @return 震动实时数据
     */
    @Override
    public EmsVibrationInstant selectEmsVibrationInstantByObjId(Long objId)
    {
        return emsVibrationInstantMapper.selectEmsVibrationInstantByObjId(objId);
    }

    /**
     * 查询震动实时数据列表
     * 
     * @param emsVibrationInstant 震动实时数据
     * @return 震动实时数据
     */
    @Override
    public List<EmsVibrationInstant> selectEmsVibrationInstantList(EmsVibrationInstant emsVibrationInstant)
    {
        return emsVibrationInstantMapper.selectEmsVibrationInstantList(emsVibrationInstant);
    }

    /**
     * 新增震动实时数据
     * 
     * @param emsVibrationInstant 震动实时数据
     * @return 结果
     */
    @Override
    public int insertEmsVibrationInstant(EmsVibrationInstant emsVibrationInstant)
    {
        return emsVibrationInstantMapper.insertEmsVibrationInstant(emsVibrationInstant);
    }

    /**
     * 修改震动实时数据
     * 
     * @param emsVibrationInstant 震动实时数据
     * @return 结果
     */
    @Override
    public int updateEmsVibrationInstant(EmsVibrationInstant emsVibrationInstant)
    {
        return emsVibrationInstantMapper.updateEmsVibrationInstant(emsVibrationInstant);
    }

    /**
     * 批量删除震动实时数据
     * 
     * @param objIds 需要删除的震动实时数据主键
     * @return 结果
     */
    @Override
    public int deleteEmsVibrationInstantByObjIds(Long[] objIds)
    {
        return emsVibrationInstantMapper.deleteEmsVibrationInstantByObjIds(objIds);
    }

    /**
     * 删除震动实时数据信息
     * 
     * @param objId 震动实时数据主键
     * @return 结果
     */
    @Override
    public int deleteEmsVibrationInstantByObjId(Long objId)
    {
        return emsVibrationInstantMapper.deleteEmsVibrationInstantByObjId(objId);
    }

    /**impl
     * 查询震动实时数据
     * @param emsVibrationInstant
     * @return
     */
    @Override
    public List<EmsVibrationInstant> selectVibrationInstantList(EmsVibrationInstant emsVibrationInstant) {
        return emsVibrationInstantMapper.selectVibrationInstantList(emsVibrationInstant);
    }
}
